<?php

namespace AuthStack\TwoFactor\Model;

interface KeyInterface
{
    /**
     * @return int
     */
    public function getID();


    /**
     * @return bool
     */
    public function isU2F();


    /**
     * @return mixed
     */
    public function getType();


    /**
     * @return string
     */
    public function getTitle();


    /**
     * @return string
     */
    public function getCreatedAt();


    /**
     * @return string
     */
    public function getUsedAt();


    /**
     * @param bool|false $show_secret_fields
     *
     * @return mixed
     */
    public function toArray($show_secret_fields = false);
}